﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Airbus
{
    internal class DrawningObjectPlane : IDrawningObject
    {
        private DrawningAirbus _airbus;

        public float Step => _airbus?.Airbus?.Step ?? 0;

        public DrawningObjectPlane(DrawningAirbus airbus)
        {
            _airbus = airbus;
        }

        public DrawningAirbus GetPlane => _airbus;

        void IDrawningObject.DrawningObject(Graphics g)
        {
            _airbus.DrawTransport(g);
        }

        public (float Left, float Right, float Top, float Bottom) GetCurrentPosition()
        {
            return _airbus?.GetCurrentPosition() ?? default;
        }

        public void MoveObject(Direction direction)
        {
            _airbus?.MoveTransport(direction);
        }

        public void SetObject(int x, int y, int width, int height)
        {
            _airbus?.SetPosition(x, y, width, height);
        }

        public void DrawningObject()
        {
            //TODO
        }

        public string GetInfo() => _airbus?.GetDataForSave();

        public static IDrawningObject Create(string data) => new DrawningObjectPlane(data.CreateDrawningPlane());

        public bool Equals(IDrawningObject? other)
        {
            if(other == null)
            {
                return false;
            }

            var otherPlane = other as DrawningObjectPlane;

            if(otherPlane == null)
            {
                return false;
            }

            var plane = _airbus.Airbus;
            var otherPlanePlane = otherPlane._airbus.Airbus;

            if(plane.Speed != otherPlanePlane.Speed)
            {
                return false;
            }

            if(plane.Weight != otherPlanePlane.Weight)
            {
                return false;
            }

            if(plane.CorpusColor != otherPlanePlane.CorpusColor)
            {
                return false;
            }

            if(plane.GetType().Name != otherPlanePlane.GetType().Name)
            {
                return false;
            }

            if (plane is EntitySuperAirbus entitySuperAirbus && otherPlanePlane is EntitySuperAirbus otherEntitySuperAirbus)
            {
                if(entitySuperAirbus.AddEngine != otherEntitySuperAirbus.AddEngine)
                {
                    return false;
                }

                if(entitySuperAirbus.AddСompartment != otherEntitySuperAirbus.AddСompartment)
                {
                    return false;
                }

                if(entitySuperAirbus.AddColor.Name != otherEntitySuperAirbus.AddColor.Name)
                {
                    return false;
                }
            }

            return true;
        }
    }
}
